/*******************************************************************************
* File Name: Timer2.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the Timer2
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_Timer2_H)
#define CY_TCPWM_Timer2_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} Timer2_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  Timer2_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define Timer2_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define Timer2_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define Timer2_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define Timer2_QUAD_ENCODING_MODES            (0lu)
#define Timer2_QUAD_AUTO_START                (1lu)

/* Signal modes */
#define Timer2_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define Timer2_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define Timer2_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define Timer2_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define Timer2_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define Timer2_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define Timer2_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define Timer2_TC_RUN_MODE                    (0lu)
#define Timer2_TC_COUNTER_MODE                (0lu)
#define Timer2_TC_COMP_CAP_MODE               (2lu)
#define Timer2_TC_PRESCALER                   (0lu)

/* Signal modes */
#define Timer2_TC_RELOAD_SIGNAL_MODE          (0lu)
#define Timer2_TC_COUNT_SIGNAL_MODE           (3lu)
#define Timer2_TC_START_SIGNAL_MODE           (0lu)
#define Timer2_TC_STOP_SIGNAL_MODE            (0lu)
#define Timer2_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define Timer2_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define Timer2_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define Timer2_TC_START_SIGNAL_PRESENT        (0lu)
#define Timer2_TC_STOP_SIGNAL_PRESENT         (0lu)
#define Timer2_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Timer2_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define Timer2_PWM_KILL_EVENT                 (0lu)
#define Timer2_PWM_STOP_EVENT                 (0lu)
#define Timer2_PWM_MODE                       (4lu)
#define Timer2_PWM_OUT_N_INVERT               (0lu)
#define Timer2_PWM_OUT_INVERT                 (0lu)
#define Timer2_PWM_ALIGN                      (0lu)
#define Timer2_PWM_RUN_MODE                   (0lu)
#define Timer2_PWM_DEAD_TIME_CYCLE            (0lu)
#define Timer2_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define Timer2_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define Timer2_PWM_COUNT_SIGNAL_MODE          (3lu)
#define Timer2_PWM_START_SIGNAL_MODE          (0lu)
#define Timer2_PWM_STOP_SIGNAL_MODE           (0lu)
#define Timer2_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define Timer2_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define Timer2_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define Timer2_PWM_START_SIGNAL_PRESENT       (0lu)
#define Timer2_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define Timer2_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Timer2_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define Timer2_TC_PERIOD_VALUE                (12000lu)
#define Timer2_TC_COMPARE_VALUE               (65535lu)
#define Timer2_TC_COMPARE_BUF_VALUE           (65535lu)
#define Timer2_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define Timer2_PWM_PERIOD_VALUE               (65535lu)
#define Timer2_PWM_PERIOD_BUF_VALUE           (65535lu)
#define Timer2_PWM_PERIOD_SWAP                (0lu)
#define Timer2_PWM_COMPARE_VALUE              (65535lu)
#define Timer2_PWM_COMPARE_BUF_VALUE          (65535lu)
#define Timer2_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define Timer2__LEFT 0
#define Timer2__RIGHT 1
#define Timer2__CENTER 2
#define Timer2__ASYMMETRIC 3

#define Timer2__X1 0
#define Timer2__X2 1
#define Timer2__X4 2

#define Timer2__PWM 4
#define Timer2__PWM_DT 5
#define Timer2__PWM_PR 6

#define Timer2__INVERSE 1
#define Timer2__DIRECT 0

#define Timer2__CAPTURE 2
#define Timer2__COMPARE 0

#define Timer2__TRIG_LEVEL 3
#define Timer2__TRIG_RISING 0
#define Timer2__TRIG_FALLING 1
#define Timer2__TRIG_BOTH 2

#define Timer2__INTR_MASK_TC 1
#define Timer2__INTR_MASK_CC_MATCH 2
#define Timer2__INTR_MASK_NONE 0
#define Timer2__INTR_MASK_TC_CC 3

#define Timer2__UNCONFIG 8
#define Timer2__TIMER 1
#define Timer2__QUAD 3
#define Timer2__PWM_SEL 7

#define Timer2__COUNT_UP 0
#define Timer2__COUNT_DOWN 1
#define Timer2__COUNT_UPDOWN0 2
#define Timer2__COUNT_UPDOWN1 3


/* Prescaler */
#define Timer2_PRESCALE_DIVBY1                ((uint32)(0u << Timer2_PRESCALER_SHIFT))
#define Timer2_PRESCALE_DIVBY2                ((uint32)(1u << Timer2_PRESCALER_SHIFT))
#define Timer2_PRESCALE_DIVBY4                ((uint32)(2u << Timer2_PRESCALER_SHIFT))
#define Timer2_PRESCALE_DIVBY8                ((uint32)(3u << Timer2_PRESCALER_SHIFT))
#define Timer2_PRESCALE_DIVBY16               ((uint32)(4u << Timer2_PRESCALER_SHIFT))
#define Timer2_PRESCALE_DIVBY32               ((uint32)(5u << Timer2_PRESCALER_SHIFT))
#define Timer2_PRESCALE_DIVBY64               ((uint32)(6u << Timer2_PRESCALER_SHIFT))
#define Timer2_PRESCALE_DIVBY128              ((uint32)(7u << Timer2_PRESCALER_SHIFT))

/* TCPWM set modes */
#define Timer2_MODE_TIMER_COMPARE             ((uint32)(Timer2__COMPARE         <<  \
                                                                  Timer2_MODE_SHIFT))
#define Timer2_MODE_TIMER_CAPTURE             ((uint32)(Timer2__CAPTURE         <<  \
                                                                  Timer2_MODE_SHIFT))
#define Timer2_MODE_QUAD                      ((uint32)(Timer2__QUAD            <<  \
                                                                  Timer2_MODE_SHIFT))
#define Timer2_MODE_PWM                       ((uint32)(Timer2__PWM             <<  \
                                                                  Timer2_MODE_SHIFT))
#define Timer2_MODE_PWM_DT                    ((uint32)(Timer2__PWM_DT          <<  \
                                                                  Timer2_MODE_SHIFT))
#define Timer2_MODE_PWM_PR                    ((uint32)(Timer2__PWM_PR          <<  \
                                                                  Timer2_MODE_SHIFT))

/* Quad Modes */
#define Timer2_MODE_X1                        ((uint32)(Timer2__X1              <<  \
                                                                  Timer2_QUAD_MODE_SHIFT))
#define Timer2_MODE_X2                        ((uint32)(Timer2__X2              <<  \
                                                                  Timer2_QUAD_MODE_SHIFT))
#define Timer2_MODE_X4                        ((uint32)(Timer2__X4              <<  \
                                                                  Timer2_QUAD_MODE_SHIFT))

/* Counter modes */
#define Timer2_COUNT_UP                       ((uint32)(Timer2__COUNT_UP        <<  \
                                                                  Timer2_UPDOWN_SHIFT))
#define Timer2_COUNT_DOWN                     ((uint32)(Timer2__COUNT_DOWN      <<  \
                                                                  Timer2_UPDOWN_SHIFT))
#define Timer2_COUNT_UPDOWN0                  ((uint32)(Timer2__COUNT_UPDOWN0   <<  \
                                                                  Timer2_UPDOWN_SHIFT))
#define Timer2_COUNT_UPDOWN1                  ((uint32)(Timer2__COUNT_UPDOWN1   <<  \
                                                                  Timer2_UPDOWN_SHIFT))

/* PWM output invert */
#define Timer2_INVERT_LINE                    ((uint32)(Timer2__INVERSE         <<  \
                                                                  Timer2_INV_OUT_SHIFT))
#define Timer2_INVERT_LINE_N                  ((uint32)(Timer2__INVERSE         <<  \
                                                                  Timer2_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define Timer2_TRIG_RISING                    ((uint32)Timer2__TRIG_RISING)
#define Timer2_TRIG_FALLING                   ((uint32)Timer2__TRIG_FALLING)
#define Timer2_TRIG_BOTH                      ((uint32)Timer2__TRIG_BOTH)
#define Timer2_TRIG_LEVEL                     ((uint32)Timer2__TRIG_LEVEL)

/* Interrupt mask */
#define Timer2_INTR_MASK_TC                   ((uint32)Timer2__INTR_MASK_TC)
#define Timer2_INTR_MASK_CC_MATCH             ((uint32)Timer2__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define Timer2_CC_MATCH_SET                   (0x00u)
#define Timer2_CC_MATCH_CLEAR                 (0x01u)
#define Timer2_CC_MATCH_INVERT                (0x02u)
#define Timer2_CC_MATCH_NO_CHANGE             (0x03u)
#define Timer2_OVERLOW_SET                    (0x00u)
#define Timer2_OVERLOW_CLEAR                  (0x04u)
#define Timer2_OVERLOW_INVERT                 (0x08u)
#define Timer2_OVERLOW_NO_CHANGE              (0x0Cu)
#define Timer2_UNDERFLOW_SET                  (0x00u)
#define Timer2_UNDERFLOW_CLEAR                (0x10u)
#define Timer2_UNDERFLOW_INVERT               (0x20u)
#define Timer2_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define Timer2_PWM_MODE_LEFT                  (Timer2_CC_MATCH_CLEAR        |   \
                                                         Timer2_OVERLOW_SET           |   \
                                                         Timer2_UNDERFLOW_NO_CHANGE)
#define Timer2_PWM_MODE_RIGHT                 (Timer2_CC_MATCH_SET          |   \
                                                         Timer2_OVERLOW_NO_CHANGE     |   \
                                                         Timer2_UNDERFLOW_CLEAR)
#define Timer2_PWM_MODE_ASYM                  (Timer2_CC_MATCH_INVERT       |   \
                                                         Timer2_OVERLOW_SET           |   \
                                                         Timer2_UNDERFLOW_CLEAR)

#if (Timer2_CY_TCPWM_V2)
    #if(Timer2_CY_TCPWM_4000)
        #define Timer2_PWM_MODE_CENTER                (Timer2_CC_MATCH_INVERT       |   \
                                                                 Timer2_OVERLOW_NO_CHANGE     |   \
                                                                 Timer2_UNDERFLOW_CLEAR)
    #else
        #define Timer2_PWM_MODE_CENTER                (Timer2_CC_MATCH_INVERT       |   \
                                                                 Timer2_OVERLOW_SET           |   \
                                                                 Timer2_UNDERFLOW_CLEAR)
    #endif /* (Timer2_CY_TCPWM_4000) */
#else
    #define Timer2_PWM_MODE_CENTER                (Timer2_CC_MATCH_INVERT       |   \
                                                             Timer2_OVERLOW_NO_CHANGE     |   \
                                                             Timer2_UNDERFLOW_CLEAR)
#endif /* (Timer2_CY_TCPWM_NEW) */

/* Command operations without condition */
#define Timer2_CMD_CAPTURE                    (0u)
#define Timer2_CMD_RELOAD                     (8u)
#define Timer2_CMD_STOP                       (16u)
#define Timer2_CMD_START                      (24u)

/* Status */
#define Timer2_STATUS_DOWN                    (1u)
#define Timer2_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   Timer2_Init(void);
void   Timer2_Enable(void);
void   Timer2_Start(void);
void   Timer2_Stop(void);

void   Timer2_SetMode(uint32 mode);
void   Timer2_SetCounterMode(uint32 counterMode);
void   Timer2_SetPWMMode(uint32 modeMask);
void   Timer2_SetQDMode(uint32 qdMode);

void   Timer2_SetPrescaler(uint32 prescaler);
void   Timer2_TriggerCommand(uint32 mask, uint32 command);
void   Timer2_SetOneShot(uint32 oneShotEnable);
uint32 Timer2_ReadStatus(void);

void   Timer2_SetPWMSyncKill(uint32 syncKillEnable);
void   Timer2_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   Timer2_SetPWMDeadTime(uint32 deadTime);
void   Timer2_SetPWMInvert(uint32 mask);

void   Timer2_SetInterruptMode(uint32 interruptMask);
uint32 Timer2_GetInterruptSourceMasked(void);
uint32 Timer2_GetInterruptSource(void);
void   Timer2_ClearInterrupt(uint32 interruptMask);
void   Timer2_SetInterrupt(uint32 interruptMask);

void   Timer2_WriteCounter(uint32 count);
uint32 Timer2_ReadCounter(void);

uint32 Timer2_ReadCapture(void);
uint32 Timer2_ReadCaptureBuf(void);

void   Timer2_WritePeriod(uint32 period);
uint32 Timer2_ReadPeriod(void);
void   Timer2_WritePeriodBuf(uint32 periodBuf);
uint32 Timer2_ReadPeriodBuf(void);

void   Timer2_WriteCompare(uint32 compare);
uint32 Timer2_ReadCompare(void);
void   Timer2_WriteCompareBuf(uint32 compareBuf);
uint32 Timer2_ReadCompareBuf(void);

void   Timer2_SetPeriodSwap(uint32 swapEnable);
void   Timer2_SetCompareSwap(uint32 swapEnable);

void   Timer2_SetCaptureMode(uint32 triggerMode);
void   Timer2_SetReloadMode(uint32 triggerMode);
void   Timer2_SetStartMode(uint32 triggerMode);
void   Timer2_SetStopMode(uint32 triggerMode);
void   Timer2_SetCountMode(uint32 triggerMode);

void   Timer2_SaveConfig(void);
void   Timer2_RestoreConfig(void);
void   Timer2_Sleep(void);
void   Timer2_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define Timer2_BLOCK_CONTROL_REG              (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Timer2_BLOCK_CONTROL_PTR              ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Timer2_COMMAND_REG                    (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Timer2_COMMAND_PTR                    ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Timer2_INTRRUPT_CAUSE_REG             (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Timer2_INTRRUPT_CAUSE_PTR             ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Timer2_CONTROL_REG                    (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__CTRL )
#define Timer2_CONTROL_PTR                    ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__CTRL )
#define Timer2_STATUS_REG                     (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__STATUS )
#define Timer2_STATUS_PTR                     ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__STATUS )
#define Timer2_COUNTER_REG                    (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__COUNTER )
#define Timer2_COUNTER_PTR                    ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__COUNTER )
#define Timer2_COMP_CAP_REG                   (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__CC )
#define Timer2_COMP_CAP_PTR                   ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__CC )
#define Timer2_COMP_CAP_BUF_REG               (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__CC_BUFF )
#define Timer2_COMP_CAP_BUF_PTR               ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__CC_BUFF )
#define Timer2_PERIOD_REG                     (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__PERIOD )
#define Timer2_PERIOD_PTR                     ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__PERIOD )
#define Timer2_PERIOD_BUF_REG                 (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Timer2_PERIOD_BUF_PTR                 ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Timer2_TRIG_CONTROL0_REG              (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Timer2_TRIG_CONTROL0_PTR              ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Timer2_TRIG_CONTROL1_REG              (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Timer2_TRIG_CONTROL1_PTR              ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Timer2_TRIG_CONTROL2_REG              (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Timer2_TRIG_CONTROL2_PTR              ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Timer2_INTERRUPT_REQ_REG              (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__INTR )
#define Timer2_INTERRUPT_REQ_PTR              ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__INTR )
#define Timer2_INTERRUPT_SET_REG              (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__INTR_SET )
#define Timer2_INTERRUPT_SET_PTR              ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__INTR_SET )
#define Timer2_INTERRUPT_MASK_REG             (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__INTR_MASK )
#define Timer2_INTERRUPT_MASK_PTR             ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__INTR_MASK )
#define Timer2_INTERRUPT_MASKED_REG           (*(reg32 *) Timer2_cy_m0s8_tcpwm_1__INTR_MASKED )
#define Timer2_INTERRUPT_MASKED_PTR           ( (reg32 *) Timer2_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define Timer2_MASK                           ((uint32)Timer2_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define Timer2_RELOAD_CC_SHIFT                (0u)
#define Timer2_RELOAD_PERIOD_SHIFT            (1u)
#define Timer2_PWM_SYNC_KILL_SHIFT            (2u)
#define Timer2_PWM_STOP_KILL_SHIFT            (3u)
#define Timer2_PRESCALER_SHIFT                (8u)
#define Timer2_UPDOWN_SHIFT                   (16u)
#define Timer2_ONESHOT_SHIFT                  (18u)
#define Timer2_QUAD_MODE_SHIFT                (20u)
#define Timer2_INV_OUT_SHIFT                  (20u)
#define Timer2_INV_COMPL_OUT_SHIFT            (21u)
#define Timer2_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define Timer2_RELOAD_CC_MASK                 ((uint32)(Timer2_1BIT_MASK        <<  \
                                                                            Timer2_RELOAD_CC_SHIFT))
#define Timer2_RELOAD_PERIOD_MASK             ((uint32)(Timer2_1BIT_MASK        <<  \
                                                                            Timer2_RELOAD_PERIOD_SHIFT))
#define Timer2_PWM_SYNC_KILL_MASK             ((uint32)(Timer2_1BIT_MASK        <<  \
                                                                            Timer2_PWM_SYNC_KILL_SHIFT))
#define Timer2_PWM_STOP_KILL_MASK             ((uint32)(Timer2_1BIT_MASK        <<  \
                                                                            Timer2_PWM_STOP_KILL_SHIFT))
#define Timer2_PRESCALER_MASK                 ((uint32)(Timer2_8BIT_MASK        <<  \
                                                                            Timer2_PRESCALER_SHIFT))
#define Timer2_UPDOWN_MASK                    ((uint32)(Timer2_2BIT_MASK        <<  \
                                                                            Timer2_UPDOWN_SHIFT))
#define Timer2_ONESHOT_MASK                   ((uint32)(Timer2_1BIT_MASK        <<  \
                                                                            Timer2_ONESHOT_SHIFT))
#define Timer2_QUAD_MODE_MASK                 ((uint32)(Timer2_3BIT_MASK        <<  \
                                                                            Timer2_QUAD_MODE_SHIFT))
#define Timer2_INV_OUT_MASK                   ((uint32)(Timer2_2BIT_MASK        <<  \
                                                                            Timer2_INV_OUT_SHIFT))
#define Timer2_MODE_MASK                      ((uint32)(Timer2_3BIT_MASK        <<  \
                                                                            Timer2_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define Timer2_CAPTURE_SHIFT                  (0u)
#define Timer2_COUNT_SHIFT                    (2u)
#define Timer2_RELOAD_SHIFT                   (4u)
#define Timer2_STOP_SHIFT                     (6u)
#define Timer2_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define Timer2_CAPTURE_MASK                   ((uint32)(Timer2_2BIT_MASK        <<  \
                                                                  Timer2_CAPTURE_SHIFT))
#define Timer2_COUNT_MASK                     ((uint32)(Timer2_2BIT_MASK        <<  \
                                                                  Timer2_COUNT_SHIFT))
#define Timer2_RELOAD_MASK                    ((uint32)(Timer2_2BIT_MASK        <<  \
                                                                  Timer2_RELOAD_SHIFT))
#define Timer2_STOP_MASK                      ((uint32)(Timer2_2BIT_MASK        <<  \
                                                                  Timer2_STOP_SHIFT))
#define Timer2_START_MASK                     ((uint32)(Timer2_2BIT_MASK        <<  \
                                                                  Timer2_START_SHIFT))

/* MASK */
#define Timer2_1BIT_MASK                      ((uint32)0x01u)
#define Timer2_2BIT_MASK                      ((uint32)0x03u)
#define Timer2_3BIT_MASK                      ((uint32)0x07u)
#define Timer2_6BIT_MASK                      ((uint32)0x3Fu)
#define Timer2_8BIT_MASK                      ((uint32)0xFFu)
#define Timer2_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define Timer2_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define Timer2_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(Timer2_QUAD_ENCODING_MODES     << Timer2_QUAD_MODE_SHIFT))       |\
         ((uint32)(Timer2_CONFIG                  << Timer2_MODE_SHIFT)))

#define Timer2_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(Timer2_PWM_STOP_EVENT          << Timer2_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(Timer2_PWM_OUT_INVERT          << Timer2_INV_OUT_SHIFT))         |\
         ((uint32)(Timer2_PWM_OUT_N_INVERT        << Timer2_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(Timer2_PWM_MODE                << Timer2_MODE_SHIFT)))

#define Timer2_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(Timer2_PWM_RUN_MODE         << Timer2_ONESHOT_SHIFT))
            
#define Timer2_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(Timer2_PWM_ALIGN            << Timer2_UPDOWN_SHIFT))

#define Timer2_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(Timer2_PWM_KILL_EVENT      << Timer2_PWM_SYNC_KILL_SHIFT))

#define Timer2_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(Timer2_PWM_DEAD_TIME_CYCLE  << Timer2_PRESCALER_SHIFT))

#define Timer2_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(Timer2_PWM_PRESCALER        << Timer2_PRESCALER_SHIFT))

#define Timer2_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(Timer2_TC_PRESCALER            << Timer2_PRESCALER_SHIFT))       |\
         ((uint32)(Timer2_TC_COUNTER_MODE         << Timer2_UPDOWN_SHIFT))          |\
         ((uint32)(Timer2_TC_RUN_MODE             << Timer2_ONESHOT_SHIFT))         |\
         ((uint32)(Timer2_TC_COMP_CAP_MODE        << Timer2_MODE_SHIFT)))
        
#define Timer2_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(Timer2_QUAD_PHIA_SIGNAL_MODE   << Timer2_COUNT_SHIFT))           |\
         ((uint32)(Timer2_QUAD_INDEX_SIGNAL_MODE  << Timer2_RELOAD_SHIFT))          |\
         ((uint32)(Timer2_QUAD_STOP_SIGNAL_MODE   << Timer2_STOP_SHIFT))            |\
         ((uint32)(Timer2_QUAD_PHIB_SIGNAL_MODE   << Timer2_START_SHIFT)))

#define Timer2_PWM_SIGNALS_MODES                                                              \
        (((uint32)(Timer2_PWM_SWITCH_SIGNAL_MODE  << Timer2_CAPTURE_SHIFT))         |\
         ((uint32)(Timer2_PWM_COUNT_SIGNAL_MODE   << Timer2_COUNT_SHIFT))           |\
         ((uint32)(Timer2_PWM_RELOAD_SIGNAL_MODE  << Timer2_RELOAD_SHIFT))          |\
         ((uint32)(Timer2_PWM_STOP_SIGNAL_MODE    << Timer2_STOP_SHIFT))            |\
         ((uint32)(Timer2_PWM_START_SIGNAL_MODE   << Timer2_START_SHIFT)))

#define Timer2_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(Timer2_TC_CAPTURE_SIGNAL_MODE  << Timer2_CAPTURE_SHIFT))         |\
         ((uint32)(Timer2_TC_COUNT_SIGNAL_MODE    << Timer2_COUNT_SHIFT))           |\
         ((uint32)(Timer2_TC_RELOAD_SIGNAL_MODE   << Timer2_RELOAD_SHIFT))          |\
         ((uint32)(Timer2_TC_STOP_SIGNAL_MODE     << Timer2_STOP_SHIFT))            |\
         ((uint32)(Timer2_TC_START_SIGNAL_MODE    << Timer2_START_SHIFT)))
        
#define Timer2_TIMER_UPDOWN_CNT_USED                                                          \
                ((Timer2__COUNT_UPDOWN0 == Timer2_TC_COUNTER_MODE)                  ||\
                 (Timer2__COUNT_UPDOWN1 == Timer2_TC_COUNTER_MODE))

#define Timer2_PWM_UPDOWN_CNT_USED                                                            \
                ((Timer2__CENTER == Timer2_PWM_ALIGN)                               ||\
                 (Timer2__ASYMMETRIC == Timer2_PWM_ALIGN))               
        
#define Timer2_PWM_PR_INIT_VALUE              (1u)
#define Timer2_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_Timer2_H */

/* [] END OF FILE */
