/*******************************************************************************
* File Name: Timer2_PM.c
* Version 2.10
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Timer2.h"

static Timer2_BACKUP_STRUCT Timer2_backup;


/*******************************************************************************
* Function Name: Timer2_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Timer2_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: Timer2_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Timer2_Sleep(void)
{
    if(0u != (Timer2_BLOCK_CONTROL_REG & Timer2_MASK))
    {
        Timer2_backup.enableState = 1u;
    }
    else
    {
        Timer2_backup.enableState = 0u;
    }

    Timer2_Stop();
    Timer2_SaveConfig();
}


/*******************************************************************************
* Function Name: Timer2_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Timer2_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: Timer2_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Timer2_Wakeup(void)
{
    Timer2_RestoreConfig();

    if(0u != Timer2_backup.enableState)
    {
        Timer2_Enable();
    }
}


/* [] END OF FILE */
